@@ -229,6 +229,13 @@ class Turkish(TurkishClass):
 
         return self.common_return(**kwargs)
 
+    def relative_pronoun(self, **kwargs):
+        proper_noun = kwargs.get('proper_noun', False)
+        self.genitive(proper_noun=proper_noun)
+        self.concat('ki')
+
+        return self.common_return(**kwargs)
+
     def privative(self, **kwargs):
         minor = self.minor()
         self.concat(f's{minor}z')
@@ -274,6 +281,94 @@ class Turkish(TurkishClass):
 
         return self.common_return(**kwargs)
 
+    def copula_simple(self, **kwargs):
+        negative = kwargs.get('negative', False)
+        question = kwargs.get('question', False)
+
+        if negative:
+            self.concat(' değil')
+
+        if question:
+            self.concat(f' m{self.minor()}')
+
+        return self.common_return(**kwargs)
+
+    def copula_present(self, **kwargs):
+        """
+            kedidir
+            kedi degildir
+        """
+
+        negative = kwargs.get('negative')
+        question = kwargs.get('question')
+
+        if negative:
+            if question:
+                self.concat(' değil midir')
+            else:
+                self.concat(' değildir')
+        else:
+            if question:
+                self.concat(f' {self.minor()}')
+            else:
+                self.apostrophes(**kwargs)
+
+            self.concat(f'{self.letter_d()}{self.letter_i()}r')
+
+        return self.common_return(**kwargs)
+
+    def copula_definite_past(self, **kwargs):
+        """
+            kediydi
+            kedi degildi
+        """
+
+        negative = kwargs.get('negative')
+        question = kwargs.get('question')
+
+        if negative:
+            if question:
+                self.concat(' değil miydi')
+            else:
+                self.concat(' değildi')
+        else:
+            if question:
+                self.concat(f' m{self.minor()}')
+            else:
+                self.apostrophes(**kwargs)
+
+            self.if_ends_with_vowel('y')
+
+            self.concat(f'{self.letter_d()}{self.minor()}')
+
+        return self.common_return(**kwargs)
+
+    def copula_indefinite_past(self, **kwargs):
+        """
+            kediymis
+            kedi degilmis
+        """
+
+        negative = kwargs.get('negative')
+        question = kwargs.get('question')
+
+        if negative:
+            if question:
+                self.concat(' değil miymiş')
+            else:
+                self.concat(' değilmiş')
+        else:
+            if question:
+                self.concat(f' m{self.minor()}')
+            else:
+                self.apostrophes(**kwargs)
+
+            self.if_ends_with_vowel('y')
+
+            self.concat(f'm{self.minor()}ş')
+
+        return self.common_return(**kwargs)
+
     def infinitive(self, **kwargs):
         """
             Mastar eki
@@ -750,29 +845,27 @@ class Turkish(TurkishClass):
         return self.common_return(**kwargs)
 
     def past_conditional_narrative(self, **kwargs):
-        letter_a = self.letter_a()
-        letter_i = self.letter_i()
         person = kwargs.get('person', 3)
         negative = kwargs.get('negative', False)
         plural = kwargs.get('plural', False)
 
         if negative:
-            self.concat(f'm{letter_a}')
+            self.concat(f'm{self.letter_a()}')
 
-        self.concat(f's{letter_a}')
+        self.concat(f's{self.letter_a()}')
 
         if person == 3 and plural:
             self.concat(f'l{self.letter_a()}r')
 
         if kwargs.get('question', False):
-            self.concat(f' m{letter_i}yd{letter_i}')
+            self.concat(f' m{self.letter_i()}yd{self.letter_i()}')
 
         self.if_condition(
             person, plural,
-            [1, False, self.concat('m')],
-            [2, False, self.concat('n')],
-            [1, True, self.concat('k')],
-            [2, True, self.concat(f'n{letter_i}z')],
+            [1, False, 'm'],
+            [2, False, 'n'],
+            [1, True, 'k'],
+            [2, True, f'n{self.letter_i()}z'],
         )
 
         return self.common_return(**kwargs)
